You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ace.apache.org by ma...@apache.org on 2012/03/16 11:05:16 UTC

svn commit: r1301412 [1/3] - in /ace/trunk: ace-client-repository-api/src/main/java/org/apache/ace/client/repository/ ace-client-repository-api/src/main/java/org/apache/ace/client/repository/helper/ ace-client-repository-api/src/main/java/org/apache/ac...

Author: marrs
Date: Fri Mar 16 10:05:14 2012
New Revision: 1301412

URL: http://svn.apache.org/viewvc?rev=1301412&view=rev
Log:
ACE-63 refactored the second project

Added:
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Artifact2FeatureAssociation.java
      - copied, changed from r1301359, ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Artifact2GroupAssociation.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Distribution2TargetAssociation.java
      - copied, changed from r1301381, ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/License2GatewayAssociation.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/DistributionObject.java
      - copied, changed from r1301381, ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/LicenseObject.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Feature2DistributionAssociation.java
      - copied, changed from r1301359, ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Group2LicenseAssociation.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/FeatureObject.java
      - copied, changed from r1301359, ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/GroupObject.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Artifact2FeatureAssociationRepository.java
      - copied, changed from r1301359, ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Artifact2GroupAssociationRepository.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Distribution2TargetAssociationRepository.java
      - copied, changed from r1301381, ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/License2GatewayAssociationRepository.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/DistributionRepository.java
      - copied, changed from r1301359, ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/LicenseRepository.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Feature2DistributionAssociationRepository.java
      - copied, changed from r1301359, ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Group2LicenseAssociationRepository.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/FeatureRepository.java
      - copied, changed from r1301359, ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/GroupRepository.java
Removed:
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Artifact2GroupAssociation.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Group2LicenseAssociation.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/GroupObject.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/License2GatewayAssociation.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/LicenseObject.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Artifact2GroupAssociationRepository.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Group2LicenseAssociationRepository.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/GroupRepository.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/License2GatewayAssociationRepository.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/LicenseRepository.java
Modified:
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/RepositoryAdminLoginContext.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/helper/ArtifactPreprocessor.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/ArtifactObject.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/DeploymentVersionObject.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/TargetObject.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/ArtifactRepository.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/DeploymentVersionRepository.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/stateful/StatefulTargetObject.java
    ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/stateful/StatefulTargetRepository.java
    ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Activator.java
    ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Artifact2GroupAssociationImpl.java
    ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Artifact2GroupAssociationRepositoryImpl.java
    ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/ArtifactObjectImpl.java
    ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/DeploymentVersionObjectImpl.java
    ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/DeploymentVersionRepositoryImpl.java
    ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/GatewayObjectImpl.java
    ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Group2LicenseAssociationImpl.java
    ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Group2LicenseAssociationRepositoryImpl.java
    ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/GroupObjectImpl.java
    ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/GroupRepositoryImpl.java
    ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/License2GatewayAssociationImpl.java
    ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/License2GatewayAssociationRepositoryImpl.java
    ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/LicenseObjectImpl.java
    ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/LicenseRepositoryImpl.java
    ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/RepoPropertyResolver.java
    ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/RepositoryAdminImpl.java
    ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/RepositoryAdminLoginContextImpl.java
    ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/stateful/impl/StatefulGatewayObjectImpl.java
    ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/stateful/impl/StatefulGatewayRepositoryImpl.java
    ace/trunk/ace-client-repository-impl/src/test/java/org/apache/ace/client/repository/impl/ModelTest.java
    ace/trunk/ace-client-rest/src/main/java/org/apache/ace/client/rest/Workspace.java
    ace/trunk/ace-integrationtests/src/test/java/org/apache/ace/it/repositoryadmin/RepositoryAdminTest.java
    ace/trunk/ace-webui-vaadin/src/main/java/org/apache/ace/webui/domain/NamedDistributionObject.java
    ace/trunk/ace-webui-vaadin/src/main/java/org/apache/ace/webui/domain/NamedFeatureObject.java
    ace/trunk/ace-webui-vaadin/src/main/java/org/apache/ace/webui/vaadin/Associations.java
    ace/trunk/ace-webui-vaadin/src/main/java/org/apache/ace/webui/vaadin/VaadinClient.java

Modified: ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/RepositoryAdminLoginContext.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/RepositoryAdminLoginContext.java?rev=1301412&r1=1301411&r2=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/RepositoryAdminLoginContext.java (original)
+++ ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/RepositoryAdminLoginContext.java Fri Mar 16 10:05:14 2012
@@ -59,7 +59,7 @@ public interface RepositoryAdminLoginCon
     public RepositoryAdminLoginContext setObrBase(URL base);
 
     /**
-     * Adds a gateway repository to this login context.
+     * Adds a target repository to this login context.
      * @param repositoryLocation The location of the repository where this set's data resides.
      * @param repositoryCustomer The customer name for the location of the repository where this set's data resides.
      * @param repositoryName The repository name for the location of the repository where this set's data resides.

Modified: ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/helper/ArtifactPreprocessor.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/helper/ArtifactPreprocessor.java?rev=1301412&r1=1301411&r2=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/helper/ArtifactPreprocessor.java (original)
+++ ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/helper/ArtifactPreprocessor.java Fri Mar 16 10:05:14 2012
@@ -24,32 +24,30 @@ import java.net.URL;
 /**
  *  An ArtifactPreprocessor processes an artifact before it is deployed.
  */
-public interface ArtifactPreprocessor
-{
-
+public interface ArtifactPreprocessor {
     /**
      * Preprocesses a single artifact, uploads it to the obr, and returns the new URL as a string.
      * @param url A string representing a URL to the original artifact.
      * @param props A PropertyResolver which can be used to fill in 'holes' in the template.
-     * @param gatewayID The gatewayID of the gateway for which this artifact is being processed.
+     * @param targetID The targetID of the target for which this artifact is being processed.
      * @param version The deployment version for which this artifact is being processed.
      * @param obrBase A base OBR to upload the new artifact to.
      * @return A URL to the new object (or the old one, if no replacing was necessary), as a string.
      * @throws java.io.IOException Thrown if reading the original artifact goes wrong, or storing the processed one.
      */
-    public String preprocess(String url, PropertyResolver props, String gatewayID, String version, URL obrBase) throws IOException;
+    public String preprocess(String url, PropertyResolver props, String targetID, String version, URL obrBase) throws IOException;
 
     /**
      * Indicates whether the template should be processed again, given the properties, and the version to which it
      * should be compared.
      * @param url A string representing a URL to the original artifact.
      * @param props A PropertyResolver which can be used to fill in 'holes' in the template.
-     * @param gatewayID The gatewayID of the gateway for which this artifact is being processed.
+     * @param targetID The targetID of the target for which this artifact is being processed.
      * @param version The deployment version for which this artifact is being processed.
      * @param fromVersion The deployment version to which the current one should be compared.
      * @return <code>false</code> if the version of the processed artifact identified by <code>fromVersion</code>
      * is identical to what would be created using the new <code>props</code>; <code>true</code> otherwise.
      * @throws java.io.IOException
      */
-    public boolean needsNewVersion(String url, PropertyResolver props, String gatewayID, String fromVersion);
-}
\ No newline at end of file
+    public boolean needsNewVersion(String url, PropertyResolver props, String targetID, String fromVersion);
+}

Copied: ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Artifact2FeatureAssociation.java (from r1301359, ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Artifact2GroupAssociation.java)
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Artifact2FeatureAssociation.java?p2=ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Artifact2FeatureAssociation.java&p1=ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Artifact2GroupAssociation.java&r1=1301359&r2=1301412&rev=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/ArtifactObject.java (original)
+++ ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/ArtifactObject.java Fri Mar 16 10:05:14 2012
@@ -72,11 +72,11 @@ public interface ArtifactObject extends 
      * Returns all <code>GroupObject</code>s this object is associated with. If there
      * are none, an empty list will be returned.
      */
-    public List<GroupObject> getGroups();
+    public List<FeatureObject> getGroups();
     /**
      * Returns all associations this artifact has with a given group.
      */
-    public List<Artifact2GroupAssociation> getAssociationsWith(GroupObject group);
+    public List<Artifact2FeatureAssociation> getAssociationsWith(FeatureObject group);
 
     /**
      * Returns the mimetype of this artifact.

Modified: ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/DeploymentVersionObject.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/DeploymentVersionObject.java?rev=1301412&r1=1301411&r2=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/DeploymentVersionObject.java (original)
+++ ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/DeploymentVersionObject.java Fri Mar 16 10:05:14 2012
@@ -29,7 +29,7 @@ import org.apache.ace.client.repository.
  */
 public interface DeploymentVersionObject extends RepositoryObject {
 
-    public static final String KEY_GATEWAYID = "gatewayID";
+    public static final String KEY_TARGETID = "targetID";
     public static final String KEY_VERSION = "version";
 
     public static final String TOPIC_ENTITY_ROOT = DeploymentVersionObject.class.getSimpleName() + "/";
@@ -40,9 +40,9 @@ public interface DeploymentVersionObject
     public static final String TOPIC_ALL = PUBLIC_TOPIC_ROOT + TOPIC_ENTITY_ROOT + TOPIC_ALL_SUFFIX;
 
     /**
-     * Gets the gateway which is related to this version.
+     * Gets the target which is related to this version.
      */
-    public String getGatewayID();
+    public String getTargetID();
 
     /**
      * Gets the version number of this deployment version.

Copied: ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Distribution2TargetAssociation.java (from r1301381, ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/License2GatewayAssociation.java)
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Distribution2TargetAssociation.java?p2=ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Distribution2TargetAssociation.java&p1=ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/License2GatewayAssociation.java&r1=1301381&r2=1301412&rev=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/License2GatewayAssociation.java (original)
+++ ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Distribution2TargetAssociation.java Fri Mar 16 10:05:14 2012
@@ -21,10 +21,10 @@ package org.apache.ace.client.repository
 import org.apache.ace.client.repository.Association;
 
 /**
- * Interface to a License2GatewayAssociation. Most functionality is defined by the generic Association.
+ * Interface to a Distribution2TargetAssociation. Most functionality is defined by the generic Association.
  */
-public interface License2GatewayAssociation extends Association<LicenseObject, TargetObject> {
-    public static final String TOPIC_ENTITY_ROOT = License2GatewayAssociation.class.getSimpleName() + "/";
+public interface Distribution2TargetAssociation extends Association<DistributionObject, TargetObject> {
+    public static final String TOPIC_ENTITY_ROOT = Distribution2TargetAssociation.class.getSimpleName() + "/";
 
     public static final String TOPIC_ADDED = PUBLIC_TOPIC_ROOT + TOPIC_ENTITY_ROOT + TOPIC_ADDED_SUFFIX;
     public static final String TOPIC_REMOVED = PUBLIC_TOPIC_ROOT + TOPIC_ENTITY_ROOT + TOPIC_REMOVED_SUFFIX;

Copied: ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/DistributionObject.java (from r1301381, ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/LicenseObject.java)
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/DistributionObject.java?p2=ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/DistributionObject.java&p1=ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/LicenseObject.java&r1=1301381&r2=1301412&rev=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/LicenseObject.java (original)
+++ ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/DistributionObject.java Fri Mar 16 10:05:14 2012
@@ -23,11 +23,11 @@ import java.util.List;
 import org.apache.ace.client.repository.RepositoryObject;
 
 /**
- * Interface to a LicenseObject. The basic functionality is defined by RepositoryObject, but extended for
- * License-specific information.
+ * Interface to a DistributionObject. The basic functionality is defined by RepositoryObject, but extended for
+ * distribution-specific information.
  */
-public interface LicenseObject extends RepositoryObject {
-    public static final String TOPIC_ENTITY_ROOT = LicenseObject.class.getSimpleName() + "/";
+public interface DistributionObject extends RepositoryObject {
+    public static final String TOPIC_ENTITY_ROOT = DistributionObject.class.getSimpleName() + "/";
 
     public static final String TOPIC_ADDED = PUBLIC_TOPIC_ROOT + TOPIC_ENTITY_ROOT + TOPIC_ADDED_SUFFIX;
     public static final String TOPIC_REMOVED = PUBLIC_TOPIC_ROOT + TOPIC_ENTITY_ROOT + TOPIC_REMOVED_SUFFIX;
@@ -38,39 +38,44 @@ public interface LicenseObject extends R
     public static final String KEY_NAME = "name";
 
     /**
-     * Returns all <code>GroupObject</code>s this object is associated with. If there
+     * Returns all <code>FeatureObject</code>s this object is associated with. If there
      * are none, an empty list will be returned.
      */
-    public List<GroupObject> getGroups();
+    public List<FeatureObject> getGroups();
+    
     /**
-     * Returns all <code>GatewayObject</code>s this object is associated with. If there
+     * Returns all <code>TargetObject</code>s this object is associated with. If there
      * are none, an empty list will be returned.
      */
     public List<TargetObject> getGateways();
 
     /**
-     * Returns all associations this license has with a given group.
+     * Returns all associations this distribution has with a given feature.
      */
-    public List<Group2LicenseAssociation> getAssociationsWith(GroupObject group);
+    public List<Feature2DistributionAssociation> getAssociationsWith(FeatureObject feature);
+
     /**
-     * Returns all associations this license has with a given gateway.
+     * Returns all associations this distribution has with a given target.
      */
-    public List<License2GatewayAssociation> getAssociationsWith(TargetObject gateway);
+    public List<Distribution2TargetAssociation> getAssociationsWith(TargetObject target);
 
     /**
-     * Returns the name of this bundle.
+     * Returns the name of this distribution.
      */
     public String getName();
+    
     /**
-     * Sets the name of this bundle.
+     * Sets the name of this distribution.
      */
     public void setName(String name);
+
     /**
-     * Returns the description of this bundle.
+     * Returns the description of this distribution.
      */
     public String getDescription();
+    
     /**
-     * Sets the description of this bundle.
+     * Sets the description of this distribution.
      */
     public void setDescription(String description);
 }

Copied: ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Feature2DistributionAssociation.java (from r1301359, ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Group2LicenseAssociation.java)
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Feature2DistributionAssociation.java?p2=ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Feature2DistributionAssociation.java&p1=ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Group2LicenseAssociation.java&r1=1301359&r2=1301412&rev=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Group2LicenseAssociation.java (original)
+++ ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Feature2DistributionAssociation.java Fri Mar 16 10:05:14 2012
@@ -21,10 +21,10 @@ package org.apache.ace.client.repository
 import org.apache.ace.client.repository.Association;
 
 /**
- * Interface to a Group2LicenseAssociation. Most functionality is defined by the generic Association.
+ * Interface to a Feature2DistributionAssociation. Most functionality is defined by the generic Association.
  */
-public interface Group2LicenseAssociation extends Association<GroupObject, LicenseObject> {
-    public static final String TOPIC_ENTITY_ROOT = Group2LicenseAssociation.class.getSimpleName() + "/";
+public interface Feature2DistributionAssociation extends Association<FeatureObject, DistributionObject> {
+    public static final String TOPIC_ENTITY_ROOT = Feature2DistributionAssociation.class.getSimpleName() + "/";
 
     public static final String TOPIC_ADDED = PUBLIC_TOPIC_ROOT + TOPIC_ENTITY_ROOT + TOPIC_ADDED_SUFFIX;
     public static final String TOPIC_REMOVED = PUBLIC_TOPIC_ROOT + TOPIC_ENTITY_ROOT + TOPIC_REMOVED_SUFFIX;

Copied: ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/FeatureObject.java (from r1301359, ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/GroupObject.java)
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/FeatureObject.java?p2=ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/FeatureObject.java&p1=ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/GroupObject.java&r1=1301359&r2=1301412&rev=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/TargetObject.java (original)
+++ ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/TargetObject.java Fri Mar 16 10:05:14 2012
@@ -34,16 +34,17 @@ public interface TargetObject extends Re
     public static final String TOPIC_ALL = PUBLIC_TOPIC_ROOT + TOPIC_ENTITY_ROOT + TOPIC_ALL_SUFFIX;
 
     /**
-     * Returns all <code>LicenseObject</code>s this object is associated with. If there
+     * Returns all <code>DistributionObject</code>s this object is associated with. If there
      * are none, an empty list will be returned.
      */
-    public List<LicenseObject> getLicenses();
+    public List<DistributionObject> getDistributions();
     /**
-     * Returns all associations this gateway has with a given license.
+     * Returns all associations this target has with a given distribution.
      */
-    public List<License2GatewayAssociation> getAssociationsWith(LicenseObject license);
+    public List<Distribution2TargetAssociation> getAssociationsWith(DistributionObject distribution);
+
     /**
-     * Gets the ID of this GatewayObject.
+     * Gets the ID of this TargetObject.
      */
     public String getID();
 
@@ -53,7 +54,7 @@ public interface TargetObject extends Re
     public void setAutoApprove(boolean approve);
 
     /**
-     * Get the auto approval value of this gateway.
+     * Get the auto approval value of this target.
      */
     public boolean getAutoApprove();
 }

Copied: ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Artifact2FeatureAssociationRepository.java (from r1301359, ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Artifact2GroupAssociationRepository.java)
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Artifact2FeatureAssociationRepository.java?p2=ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Artifact2FeatureAssociationRepository.java&p1=ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Artifact2GroupAssociationRepository.java&r1=1301359&r2=1301412&rev=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/DeploymentVersionRepository.java (original)
+++ ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/DeploymentVersionRepository.java Fri Mar 16 10:05:14 2012
@@ -20,21 +20,21 @@ public interface DeploymentVersionReposi
     public DeploymentVersionObject create(Map<String, String> attributes, Map<String, String> tags, DeploymentArtifact[] artifacts);
 
     /**
-     * Gets all available deployment versions for this gateway. If none can be
+     * Gets all available deployment versions for this target. If none can be
      * found, an empty list will be returned.
-     * @param gatewayID The gateway to be used.
+     * @param targetID The target to be used.
      * @return A list of <code>DeploymentVersionObject</code>s which are related to
-     * this gateway, sorted lexically by version.
+     * this target, sorted lexically by version.
      */
-    public List<DeploymentVersionObject> getDeploymentVersions(String gatewayID);
+    public List<DeploymentVersionObject> getDeploymentVersions(String targetID);
 
     /**
-     * Get the most recent known deployment version for a given gateway.
-     * @param gatewayID The gateway to be used.
+     * Get the most recent known deployment version for a given target.
+     * @param targetID The target to be used.
      * @return A <code>DeploymentVersionObject</code> which is the most recent one to be deployed
-     * to the gateway. If none can be found, <code>null</code> will be returned.
+     * to the target. If none can be found, <code>null</code> will be returned.
      */
-    public DeploymentVersionObject getMostRecentDeploymentVersion(String gatewayID);
+    public DeploymentVersionObject getMostRecentDeploymentVersion(String targetID);
 
     /**
      * Creates a DeploymentArtifact object.

Copied: ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Distribution2TargetAssociationRepository.java (from r1301381, ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/License2GatewayAssociationRepository.java)
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Distribution2TargetAssociationRepository.java?p2=ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Distribution2TargetAssociationRepository.java&p1=ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/License2GatewayAssociationRepository.java&r1=1301381&r2=1301412&rev=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/License2GatewayAssociationRepository.java (original)
+++ ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Distribution2TargetAssociationRepository.java Fri Mar 16 10:05:14 2012
@@ -20,19 +20,19 @@ package org.apache.ace.client.repository
 
 import org.apache.ace.client.repository.AssociationRepository;
 import org.apache.ace.client.repository.object.TargetObject;
-import org.apache.ace.client.repository.object.License2GatewayAssociation;
-import org.apache.ace.client.repository.object.LicenseObject;
+import org.apache.ace.client.repository.object.Distribution2TargetAssociation;
+import org.apache.ace.client.repository.object.DistributionObject;
 
 /**
- * Interface to a License2GatewayAssociationRepository. The functionality is defined by the generic AssociationRepository.
+ * Interface to a Distribution2TargetAssociationRepository. The functionality is defined by the generic AssociationRepository.
  */
-public interface License2GatewayAssociationRepository extends AssociationRepository<LicenseObject, TargetObject, License2GatewayAssociation> {
+public interface Distribution2TargetAssociationRepository extends AssociationRepository<DistributionObject, TargetObject, Distribution2TargetAssociation> {
     /**
-     * Creates an assocation from a given license to multiple gateways, which correspond to the given
-     * filter string. For parameters to use in the filter, see <code>GatewayObject</code>'s <code>KEY_</code> constants.
-     * @param license A license object for the left side of this association.
-     * @param gatewayFilter An LDAP-filter for the gateways to use.
+     * Creates an assocation from a given distribution to multiple targets, which correspond to the given
+     * filter string. For parameters to use in the filter, see <code>TargetObject</code>'s <code>KEY_</code> constants.
+     * @param distribution A distribution object for the left side of this association.
+     * @param targetFilter An LDAP-filter for the targets to use.
      * @return The newly created association.
      */
-    public License2GatewayAssociation createLicense2GatewayFilter(LicenseObject license, String gatewayFilter);
+    public Distribution2TargetAssociation createDistribution2TargetFilter(DistributionObject distribution, String targetFilter);
 }

Copied: ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/DistributionRepository.java (from r1301359, ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/LicenseRepository.java)
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/DistributionRepository.java?p2=ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/DistributionRepository.java&p1=ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/LicenseRepository.java&r1=1301359&r2=1301412&rev=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/LicenseRepository.java (original)
+++ ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/DistributionRepository.java Fri Mar 16 10:05:14 2012
@@ -19,10 +19,10 @@
 package org.apache.ace.client.repository.repository;
 
 import org.apache.ace.client.repository.ObjectRepository;
-import org.apache.ace.client.repository.object.LicenseObject;
+import org.apache.ace.client.repository.object.DistributionObject;
 
 /**
- * Interface to a LicenseRepository. The functionality is defined by the generic AssociationRepository.
+ * Interface to a DistributionRepository. The functionality is defined by the generic AssociationRepository.
  */
-public interface LicenseRepository extends ObjectRepository<LicenseObject>{
+public interface DistributionRepository extends ObjectRepository<DistributionObject> {
 }

Copied: ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Feature2DistributionAssociationRepository.java (from r1301359, ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Group2LicenseAssociationRepository.java)
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Feature2DistributionAssociationRepository.java?p2=ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Feature2DistributionAssociationRepository.java&p1=ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Group2LicenseAssociationRepository.java&r1=1301359&r2=1301412&rev=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Group2LicenseAssociationRepository.java (original)
+++ ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Feature2DistributionAssociationRepository.java Fri Mar 16 10:05:14 2012
@@ -19,12 +19,12 @@
 package org.apache.ace.client.repository.repository;
 
 import org.apache.ace.client.repository.AssociationRepository;
-import org.apache.ace.client.repository.object.Group2LicenseAssociation;
-import org.apache.ace.client.repository.object.GroupObject;
-import org.apache.ace.client.repository.object.LicenseObject;
+import org.apache.ace.client.repository.object.Feature2DistributionAssociation;
+import org.apache.ace.client.repository.object.FeatureObject;
+import org.apache.ace.client.repository.object.DistributionObject;
 
 /**
- * Interface to a Group2LicenseAssociationRepository. The functionality is defined by the generic AssociationRepository.
+ * Interface to a Feature2DistributionAssociationRepository. The functionality is defined by the generic AssociationRepository.
  */
-public interface Group2LicenseAssociationRepository extends AssociationRepository<GroupObject, LicenseObject, Group2LicenseAssociation> {
+public interface Feature2DistributionAssociationRepository extends AssociationRepository<FeatureObject, DistributionObject, Feature2DistributionAssociation> {
 }

Copied: ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/FeatureRepository.java (from r1301359, ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/GroupRepository.java)
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/FeatureRepository.java?p2=ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/FeatureRepository.java&p1=ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/GroupRepository.java&r1=1301359&r2=1301412&rev=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/stateful/StatefulTargetObject.java (original)
+++ ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/stateful/StatefulTargetObject.java Fri Mar 16 10:05:14 2012
@@ -24,12 +24,12 @@ import org.apache.ace.client.repository.
 import org.apache.ace.client.repository.object.ArtifactObject;
 import org.apache.ace.client.repository.object.DeploymentArtifact;
 import org.apache.ace.client.repository.object.TargetObject;
-import org.apache.ace.client.repository.object.License2GatewayAssociation;
-import org.apache.ace.client.repository.object.LicenseObject;
+import org.apache.ace.client.repository.object.Distribution2TargetAssociation;
+import org.apache.ace.client.repository.object.DistributionObject;
 import org.apache.ace.log.LogEvent;
 
 /**
- * <code>StatefulGatewayObject</code> represents the information that a <code>GatewayObject</code>
+ * Represents the information that a <code>TargetObject</code>
  * has, plus added functionality for gathering information from a deployment repository and,
  * optionally, from an AuditLog.
  */
@@ -39,10 +39,10 @@ public interface StatefulTargetObject ex
     public static final String TOPIC_REMOVED = StatefulTargetObject.class.getName().replace('.', '/') + "/REMOVED";
     public static final String TOPIC_CHANGED = StatefulTargetObject.class.getName().replace('.', '/') + "/CHANGED";
     public static final String TOPIC_STATUS_CHANGED = StatefulTargetObject.class.getName().replace('.', '/') + "/STATUS_CHANGED";
-    /** Indicates a change to the audit events for the StatefulGatewayObject in "entity".*/
+    /** Indicates a change to the audit events for the StatefulTargetObject in "entity".*/
     public static final String TOPIC_AUDITEVENTS_CHANGED = StatefulTargetObject.class.getName().replace('.', '/') + "/AUDITEVENTS_CHANGED";
     /** Key used in the event with topic <code>TOPIC_AUDITEVENTS_CHANGED</code>. Contains a List<LogDescriptor> containing all
-     *  events we have not seen yet. NOTE: The first auditevent "change" causing the <code>StatefulGatewayObject</code> to
+     *  events we have not seen yet. NOTE: The first auditevent "change" causing the <code>StatefulTargetObject</code> to
      *  be instantiated will trigger a <code>TOPIC_AUDITEVENTS_CHANGED</code> event *before* a <code>TOPIC_ADDED</code> event. */
     public static final String KEY_AUDITEVENTS = "auditevents";
     public static final String TOPIC_ALL = StatefulTargetObject.class.getName().replace('.', '/') + "/*";
@@ -64,49 +64,49 @@ public interface StatefulTargetObject ex
     public final static String UNKNOWN_VERSION = "(unknown)";
 
     /**
-     * Gets the current registration status of the gateway.
+     * Gets the current registration status of the target.
      */
     public RegistrationState getRegistrationState();
 
     /**
-     * Gets the current store status of the gateway.
+     * Gets the current store status of the target.
      */
     public StoreState getStoreState();
 
     /**
-     * Gets the current provisioning status of the gateway.
+     * Gets the current provisioning status of the target.
      */
     public ProvisioningState getProvisioningState();
 
     /**
-     * Gets the most recent deployment package version on the gateway, according
+     * Gets the most recent deployment package version on the target, according
      * to the deployment repository. If no version can be determined,
      * <code>UNKNOWN_VERSION</code> will be returned.
      */
     public String getCurrentVersion();
 
     /**
-     * Gets the list of AuditLog Events for this gateway. If no auditlog events
+     * Gets the list of AuditLog Events for this target. If no auditlog events
      * can be found, and empty list will be returned. The events are ordered ascending by timestamp.
      */
     public List<LogEvent> getAuditEvents();
 
     /**
-     * Registers this gateway, which for now only exists in the AuditLog, into the
-     * <code>GatewayRepository</code>.
+     * Registers this target, which for now only exists in the AuditLog, into the
+     * <code>TargetRepository</code>.
      * @throws IllegalStateException when the precondition is not met, i.e., the
-     * gateway is not known only in the AuditLog, but also in the <code>GatewayRepository</code>.
+     * target is not known only in the AuditLog, but also in the <code>TargetRepository</code>.
      */
     public void register() throws IllegalStateException;
 
     /**
-     * Indicates whether this <code>StatefulGatewayObject</code> is backed by a <code>GatewayObject</code>.
-     * @return whether this <code>StatefulGatewayObject</code> is backed by a <code>GatewayObject</code>.
+     * Indicates whether this <code>StatefulTargetObject</code> is backed by a <code>TargetObject</code>.
+     * @return whether this <code>StatefulTargetObject</code> is backed by a <code>TargetObject</code>.
      */
     public boolean isRegistered();
 
     /**
-     * Approves all differences between what is currently in the shop and gateway operator
+     * Approves all differences between what is currently in the shop and target operator
      * repository, and the deployment repository. This will generate a new version in the
      * deployment repository.
      * @return The number of the new version.
@@ -116,7 +116,7 @@ public interface StatefulTargetObject ex
 
     /**
      * Indicates whether an <code>approve()</code> is necessary, i.e., there is a difference between
-     * the set of bundles for this gateway according to the shop, and according to the deployment
+     * the set of artifacts for this target according to the shop, and according to the deployment
      * repository.
      * @return <code>true</code> if there is a difference between the shop and deployment repository;
      * <code>false</code> otherwise.
@@ -124,28 +124,28 @@ public interface StatefulTargetObject ex
     public boolean needsApprove();
 
     /**
-     * Returns the auto-approval flag for this gateway.
+     * Returns the auto-approval flag for this target.
      * @return <code>true</code> if auto approve has been set;
      * <code>false</code> otherwise.
      */
     public boolean getAutoApprove();
 
     /**
-     * Set the auto approve value for this gateway, the property is stored within the gateway
+     * Set the auto approve value for this target, the property is stored within the target
      * @param approve <code>true</code> to enable auto approve;
      * <code>false</code> otherwise.
      */
     public void setAutoApprove(boolean approve);
 
     /**
-     * Gets the list of artifact objects that should be on the gateway, according to the shop.
-     * @return the list of artifact objects that should be on the gateway, according to the shop.
+     * Gets the list of artifact objects that should be on the target, according to the shop.
+     * @return the list of artifact objects that should be on the target, according to the shop.
      */
     public ArtifactObject[] getArtifactsFromShop();
 
     /**
-     * Gets the list of deployment artifacts that should be on the gateway, according to the deployment repository.
-     * @return the list of artifact objects that should be on the gateway, according to the deployment repository.
+     * Gets the list of deployment artifacts that should be on the target, according to the deployment repository.
+     * @return the list of artifact objects that should be on the target, according to the deployment repository.
      */
     public DeploymentArtifact[] getArtifactsFromDeployment();
 
@@ -157,39 +157,39 @@ public interface StatefulTargetObject ex
     public String getLastInstallVersion();
 
     /**
-     * Returns whether the last install on the gateway way successful.
+     * Returns whether the last install on the target was successful.
      * @return <code>true</code> if there information about a last install and
      * that was successful, <code>false</code> otherwise.
      */
     public boolean getLastInstallSuccess();
 
     /**
-     * Signals to the object that the outcome of a given install on the gateway
+     * Signals to the object that the outcome of a given install on the target
      * is 'seen', and that the <code>ProvisioningState</code> can now return to <code>Idle</code>.
      * @param version A string representing a version.
      */
     public void acknowledgeInstallVersion(String version);
 
     /**
-     * Gets the underlying <code>GatewayObject</code> of this <code>StatefulGatewayObject</code>.
-     * @return The <code>GatewayObject</code> linked to this <code>StatefulGatewayObject</code>; if none
+     * Gets the underlying <code>TargetObject</code> of this <code>StatefulTargetObject</code>.
+     * @return The <code>TargetObject</code> linked to this <code>StatefulTargetObject</code>; if none
      * is available, an <code>IllegalStateException</code> will be thrown.
      */
-    public TargetObject getGatewayObject();
+    public TargetObject getTargetObject();
 
     /**
-     * Returns all <code>LicenseObject</code>s this object is associated with. If there
+     * Returns all <code>DistributionObject</code>s this object is associated with. If there
      * are none, an empty list will be returned.
      */
-    public List<LicenseObject> getLicenses();
+    public List<DistributionObject> getDistributions();
 
     /**
-     * Returns all associations this gateway has with a given license.
+     * Returns all associations this target has with a given distribution.
      */
-    public List<License2GatewayAssociation> getAssociationsWith(LicenseObject license);
+    public List<Distribution2TargetAssociation> getAssociationsWith(DistributionObject distribution);
 
     /**
-     * Gets the ID of this GatewayObject.
+     * Gets the ID of this TargetObject.
      */
     public String getID();
 

Modified: ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/stateful/StatefulTargetRepository.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/stateful/StatefulTargetRepository.java?rev=1301412&r1=1301411&r2=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Activator.java (original)
+++ ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Activator.java Fri Mar 16 10:05:14 2012
@@ -26,14 +26,14 @@ import java.util.Map;
 import org.apache.ace.client.repository.RepositoryAdmin;
 import org.apache.ace.client.repository.SessionFactory;
 import org.apache.ace.client.repository.helper.bundle.BundleHelper;
-import org.apache.ace.client.repository.object.Artifact2GroupAssociation;
+import org.apache.ace.client.repository.object.Artifact2FeatureAssociation;
 import org.apache.ace.client.repository.object.ArtifactObject;
 import org.apache.ace.client.repository.object.DeploymentVersionObject;
 import org.apache.ace.client.repository.object.TargetObject;
-import org.apache.ace.client.repository.object.Group2LicenseAssociation;
-import org.apache.ace.client.repository.object.GroupObject;
-import org.apache.ace.client.repository.object.License2GatewayAssociation;
-import org.apache.ace.client.repository.object.LicenseObject;
+import org.apache.ace.client.repository.object.Feature2DistributionAssociation;
+import org.apache.ace.client.repository.object.FeatureObject;
+import org.apache.ace.client.repository.object.Distribution2TargetAssociation;
+import org.apache.ace.client.repository.object.DistributionObject;
 import org.apache.ace.client.repository.repository.ArtifactRepository;
 import org.apache.ace.client.repository.repository.DeploymentVersionRepository;
 import org.apache.ace.client.repository.repository.TargetRepository;
@@ -121,11 +121,11 @@ public class Activator extends Dependenc
         Dictionary topic = new Hashtable();
         topic.put(EventConstants.EVENT_TOPIC, new String[] {
             ArtifactObject.TOPIC_ALL,
-            Artifact2GroupAssociation.TOPIC_ALL,
-            GroupObject.TOPIC_ALL,
-            Group2LicenseAssociation.TOPIC_ALL,
-            LicenseObject.TOPIC_ALL,
-            License2GatewayAssociation.TOPIC_ALL,
+            Artifact2FeatureAssociation.TOPIC_ALL,
+            FeatureObject.TOPIC_ALL,
+            Feature2DistributionAssociation.TOPIC_ALL,
+            DistributionObject.TOPIC_ALL,
+            Distribution2TargetAssociation.TOPIC_ALL,
             TargetObject.TOPIC_ALL,
             DeploymentVersionObject.TOPIC_ALL,
             RepositoryAdmin.TOPIC_REFRESH, RepositoryAdmin.TOPIC_LOGIN});

Modified: ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Artifact2GroupAssociationImpl.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Artifact2GroupAssociationImpl.java?rev=1301412&r1=1301411&r2=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Artifact2GroupAssociationImpl.java (original)
+++ ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Artifact2GroupAssociationImpl.java Fri Mar 16 10:05:14 2012
@@ -20,9 +20,9 @@ package org.apache.ace.client.repository
 
 import java.util.Map;
 
-import org.apache.ace.client.repository.object.Artifact2GroupAssociation;
+import org.apache.ace.client.repository.object.Artifact2FeatureAssociation;
 import org.apache.ace.client.repository.object.ArtifactObject;
-import org.apache.ace.client.repository.object.GroupObject;
+import org.apache.ace.client.repository.object.FeatureObject;
 import org.osgi.framework.InvalidSyntaxException;
 
 import com.thoughtworks.xstream.io.HierarchicalStreamReader;
@@ -31,18 +31,18 @@ import com.thoughtworks.xstream.io.Hiera
  * Implementation class for the Artifact2GroupAssociation. For 'what it does', see Artifact2GroupAssociation,
  * for 'how it works', see AssociationImpl.
  */
-public class Artifact2GroupAssociationImpl extends AssociationImpl<ArtifactObject, GroupObject, Artifact2GroupAssociation> implements Artifact2GroupAssociation {
+public class Artifact2GroupAssociationImpl extends AssociationImpl<ArtifactObject, FeatureObject, Artifact2FeatureAssociation> implements Artifact2FeatureAssociation {
     private final static String XML_NODE = "artifact2group";
 
     public Artifact2GroupAssociationImpl(Map<String, String> attributes, ChangeNotifier notifier, ArtifactRepositoryImpl artifactRepository, GroupRepositoryImpl groupRepository) throws InvalidSyntaxException {
-        super(attributes, notifier, ArtifactObject.class, GroupObject.class, artifactRepository, groupRepository, XML_NODE);
+        super(attributes, notifier, ArtifactObject.class, FeatureObject.class, artifactRepository, groupRepository, XML_NODE);
     }
 
     public Artifact2GroupAssociationImpl(Map<String, String> attributes, Map<String, String> tags, ChangeNotifier notifier, ArtifactRepositoryImpl artifactRepository, GroupRepositoryImpl groupRepository) throws InvalidSyntaxException {
-        super(attributes, tags, notifier, ArtifactObject.class, GroupObject.class, artifactRepository, groupRepository, XML_NODE);
+        super(attributes, tags, notifier, ArtifactObject.class, FeatureObject.class, artifactRepository, groupRepository, XML_NODE);
     }
 
     public Artifact2GroupAssociationImpl(HierarchicalStreamReader reader, ChangeNotifier notifier, ArtifactRepositoryImpl artifactRepository, GroupRepositoryImpl groupRepository) throws InvalidSyntaxException {
-        super(reader, notifier, ArtifactObject.class, GroupObject.class, null, null, artifactRepository, groupRepository, XML_NODE);
+        super(reader, notifier, ArtifactObject.class, FeatureObject.class, null, null, artifactRepository, groupRepository, XML_NODE);
     }
 }

Modified: ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Artifact2GroupAssociationRepositoryImpl.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Artifact2GroupAssociationRepositoryImpl.java?rev=1301412&r1=1301411&r2=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Artifact2GroupAssociationRepositoryImpl.java (original)
+++ ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Artifact2GroupAssociationRepositoryImpl.java Fri Mar 16 10:05:14 2012
@@ -20,10 +20,10 @@ package org.apache.ace.client.repository
 
 import java.util.Map;
 
-import org.apache.ace.client.repository.object.Artifact2GroupAssociation;
+import org.apache.ace.client.repository.object.Artifact2FeatureAssociation;
 import org.apache.ace.client.repository.object.ArtifactObject;
-import org.apache.ace.client.repository.object.GroupObject;
-import org.apache.ace.client.repository.repository.Artifact2GroupAssociationRepository;
+import org.apache.ace.client.repository.object.FeatureObject;
+import org.apache.ace.client.repository.repository.Artifact2FeatureAssociationRepository;
 import org.osgi.framework.InvalidSyntaxException;
 
 import com.thoughtworks.xstream.io.HierarchicalStreamReader;
@@ -32,7 +32,7 @@ import com.thoughtworks.xstream.io.Hiera
  * Implementation class for the Artifact2GroupAssociationRepository. For 'what it does', see Artifact2GroupAssociationRepository,
  * for 'how it works', see AssociationRepositoryImpl.
  */
-public class Artifact2GroupAssociationRepositoryImpl extends AssociationRepositoryImpl<ArtifactObject, GroupObject, Artifact2GroupAssociationImpl, Artifact2GroupAssociation> implements Artifact2GroupAssociationRepository {
+public class Artifact2GroupAssociationRepositoryImpl extends AssociationRepositoryImpl<ArtifactObject, FeatureObject, Artifact2GroupAssociationImpl, Artifact2FeatureAssociation> implements Artifact2FeatureAssociationRepository {
     private final static String XML_NODE = "artifacts2groups";
 
     private final ArtifactRepositoryImpl m_bundleRepository;

Modified: ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/ArtifactObjectImpl.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/ArtifactObjectImpl.java?rev=1301412&r1=1301411&r2=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/ArtifactObjectImpl.java (original)
+++ ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/ArtifactObjectImpl.java Fri Mar 16 10:05:14 2012
@@ -23,9 +23,9 @@ import java.util.List;
 import java.util.Map;
 
 import org.apache.ace.client.repository.helper.ArtifactHelper;
-import org.apache.ace.client.repository.object.Artifact2GroupAssociation;
+import org.apache.ace.client.repository.object.Artifact2FeatureAssociation;
 import org.apache.ace.client.repository.object.ArtifactObject;
-import org.apache.ace.client.repository.object.GroupObject;
+import org.apache.ace.client.repository.object.FeatureObject;
 
 import com.thoughtworks.xstream.io.HierarchicalStreamReader;
 
@@ -68,12 +68,12 @@ public class ArtifactObjectImpl extends 
         m_repo = repo;
     }
 
-    public List<GroupObject> getGroups() {
-        return getAssociations(GroupObject.class);
+    public List<FeatureObject> getGroups() {
+        return getAssociations(FeatureObject.class);
     }
 
-    public List<Artifact2GroupAssociation> getAssociationsWith(GroupObject group) {
-        return getAssociationsWith(group, GroupObject.class, Artifact2GroupAssociation.class);
+    public List<Artifact2FeatureAssociation> getAssociationsWith(FeatureObject group) {
+        return getAssociationsWith(group, FeatureObject.class, Artifact2FeatureAssociation.class);
     }
 
     @Override

Modified: ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/DeploymentVersionObjectImpl.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/DeploymentVersionObjectImpl.java?rev=1301412&r1=1301411&r2=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/DeploymentVersionObjectImpl.java (original)
+++ ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/DeploymentVersionObjectImpl.java Fri Mar 16 10:05:14 2012
@@ -44,11 +44,11 @@ public class DeploymentVersionObjectImpl
      * @param notifier A change notifier to be used by this object.
      */
     DeploymentVersionObjectImpl(Map<String, String> attributes, ChangeNotifier notifier) {
-        super(checkAttributes(attributes, new String[] {KEY_GATEWAYID, KEY_VERSION}, new boolean[] {false, false}), notifier, XML_NODE);
+        super(checkAttributes(attributes, new String[] {KEY_TARGETID, KEY_VERSION}, new boolean[] {false, false}), notifier, XML_NODE);
     }
 
     DeploymentVersionObjectImpl(Map<String, String> attributes, Map<String, String> tags, ChangeNotifier notifier) {
-        super(checkAttributes(attributes, new String[] {KEY_GATEWAYID, KEY_VERSION}, new boolean[] {false, false}), tags, notifier, XML_NODE);
+        super(checkAttributes(attributes, new String[] {KEY_TARGETID, KEY_VERSION}, new boolean[] {false, false}), tags, notifier, XML_NODE);
     }
 
     DeploymentVersionObjectImpl(HierarchicalStreamReader reader, ChangeNotifier notifier) {
@@ -93,14 +93,14 @@ public class DeploymentVersionObjectImpl
         writer.endNode();
     }
 
-    private static String[] DEFINING_KEYS = new String[] {KEY_GATEWAYID, KEY_VERSION};
+    private static String[] DEFINING_KEYS = new String[] {KEY_TARGETID, KEY_VERSION};
     @Override
     String[] getDefiningKeys() {
         return DEFINING_KEYS;
     }
 
-    public String getGatewayID() {
-        return getAttribute(KEY_GATEWAYID);
+    public String getTargetID() {
+        return getAttribute(KEY_TARGETID);
     }
 
     public String getVersion() {

Modified: ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/DeploymentVersionRepositoryImpl.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/DeploymentVersionRepositoryImpl.java?rev=1301412&r1=1301411&r2=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/DeploymentVersionRepositoryImpl.java (original)
+++ ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/DeploymentVersionRepositoryImpl.java Fri Mar 16 10:05:14 2012
@@ -94,7 +94,7 @@ public class DeploymentVersionRepository
     public List<DeploymentVersionObject> getDeploymentVersions(String gatewayID) {
         List<DeploymentVersionObject> result = null;
             try {
-                result = get(createFilter("(" + DeploymentVersionObject.KEY_GATEWAYID + "=" + RepositoryUtil.escapeFilterValue(gatewayID) + ")"));
+                result = get(createFilter("(" + DeploymentVersionObject.KEY_TARGETID + "=" + RepositoryUtil.escapeFilterValue(gatewayID) + ")"));
                 Collections.sort(result, versionComparator);
             }
             catch (InvalidSyntaxException e) {

Modified: ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/GatewayObjectImpl.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/GatewayObjectImpl.java?rev=1301412&r1=1301411&r2=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/GatewayObjectImpl.java (original)
+++ ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/GatewayObjectImpl.java Fri Mar 16 10:05:14 2012
@@ -22,8 +22,8 @@ import java.util.List;
 import java.util.Map;
 
 import org.apache.ace.client.repository.object.TargetObject;
-import org.apache.ace.client.repository.object.License2GatewayAssociation;
-import org.apache.ace.client.repository.object.LicenseObject;
+import org.apache.ace.client.repository.object.Distribution2TargetAssociation;
+import org.apache.ace.client.repository.object.DistributionObject;
 
 import com.thoughtworks.xstream.io.HierarchicalStreamReader;
 
@@ -49,16 +49,16 @@ public class GatewayObjectImpl extends R
         }
     }
 
-    public List<LicenseObject> getLicenses() {
-        return getAssociations(LicenseObject.class);
+    public List<DistributionObject> getDistributions() {
+        return getAssociations(DistributionObject.class);
     }
 
     public String getID() {
         return getAttribute(KEY_ID);
     }
 
-    public List<License2GatewayAssociation> getAssociationsWith(LicenseObject license) {
-        return getAssociationsWith(license, LicenseObject.class, License2GatewayAssociation.class);
+    public List<Distribution2TargetAssociation> getAssociationsWith(DistributionObject license) {
+        return getAssociationsWith(license, DistributionObject.class, Distribution2TargetAssociation.class);
     }
 
     private static String[] DEFINING_KEYS = new String[] {KEY_ID};

Modified: ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Group2LicenseAssociationImpl.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Group2LicenseAssociationImpl.java?rev=1301412&r1=1301411&r2=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Group2LicenseAssociationImpl.java (original)
+++ ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Group2LicenseAssociationImpl.java Fri Mar 16 10:05:14 2012
@@ -20,9 +20,9 @@ package org.apache.ace.client.repository
 
 import java.util.Map;
 
-import org.apache.ace.client.repository.object.Group2LicenseAssociation;
-import org.apache.ace.client.repository.object.GroupObject;
-import org.apache.ace.client.repository.object.LicenseObject;
+import org.apache.ace.client.repository.object.Feature2DistributionAssociation;
+import org.apache.ace.client.repository.object.FeatureObject;
+import org.apache.ace.client.repository.object.DistributionObject;
 import org.osgi.framework.InvalidSyntaxException;
 
 import com.thoughtworks.xstream.io.HierarchicalStreamReader;
@@ -31,16 +31,16 @@ import com.thoughtworks.xstream.io.Hiera
  * Implementation class for the Group2LicenseAssociation. For 'what it does', see Group2LicenseAssociation,
  * for 'how it works', see AssociationImpl.
  */
-public class Group2LicenseAssociationImpl extends AssociationImpl<GroupObject, LicenseObject, Group2LicenseAssociation> implements Group2LicenseAssociation {
+public class Group2LicenseAssociationImpl extends AssociationImpl<FeatureObject, DistributionObject, Feature2DistributionAssociation> implements Feature2DistributionAssociation {
     private final static String XML_NODE = "group2license";
 
     public Group2LicenseAssociationImpl(Map<String, String> attributes, ChangeNotifier notifier, GroupRepositoryImpl groupRepository, LicenseRepositoryImpl licenseRepository) throws InvalidSyntaxException {
-        super(attributes, notifier, GroupObject.class, LicenseObject.class, groupRepository, licenseRepository, XML_NODE);
+        super(attributes, notifier, FeatureObject.class, DistributionObject.class, groupRepository, licenseRepository, XML_NODE);
     }
     public Group2LicenseAssociationImpl(Map<String, String> attributes, Map<String, String> tags, ChangeNotifier notifier, GroupRepositoryImpl groupRepository, LicenseRepositoryImpl licenseRepository) throws InvalidSyntaxException {
-        super(attributes, tags, notifier, GroupObject.class, LicenseObject.class, groupRepository, licenseRepository, XML_NODE);
+        super(attributes, tags, notifier, FeatureObject.class, DistributionObject.class, groupRepository, licenseRepository, XML_NODE);
     }
     public Group2LicenseAssociationImpl(HierarchicalStreamReader reader, ChangeNotifier notifier, GroupRepositoryImpl groupRepository, LicenseRepositoryImpl licenseRepository) throws InvalidSyntaxException {
-        super(reader, notifier, GroupObject.class, LicenseObject.class, null, null, groupRepository, licenseRepository, XML_NODE);
+        super(reader, notifier, FeatureObject.class, DistributionObject.class, null, null, groupRepository, licenseRepository, XML_NODE);
     }
 }

Modified: ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Group2LicenseAssociationRepositoryImpl.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Group2LicenseAssociationRepositoryImpl.java?rev=1301412&r1=1301411&r2=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Group2LicenseAssociationRepositoryImpl.java (original)
+++ ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Group2LicenseAssociationRepositoryImpl.java Fri Mar 16 10:05:14 2012
@@ -20,10 +20,10 @@ package org.apache.ace.client.repository
 
 import java.util.Map;
 
-import org.apache.ace.client.repository.object.Group2LicenseAssociation;
-import org.apache.ace.client.repository.object.GroupObject;
-import org.apache.ace.client.repository.object.LicenseObject;
-import org.apache.ace.client.repository.repository.Group2LicenseAssociationRepository;
+import org.apache.ace.client.repository.object.Feature2DistributionAssociation;
+import org.apache.ace.client.repository.object.FeatureObject;
+import org.apache.ace.client.repository.object.DistributionObject;
+import org.apache.ace.client.repository.repository.Feature2DistributionAssociationRepository;
 import org.osgi.framework.InvalidSyntaxException;
 
 import com.thoughtworks.xstream.io.HierarchicalStreamReader;
@@ -32,7 +32,7 @@ import com.thoughtworks.xstream.io.Hiera
  * Implementation class for the Group2LicenseAssociationRepository. For 'what it does', see Group2LicenseAssociationRepository,
  * for 'how it works', see AssociationRepositoryImpl.
  */
-public class Group2LicenseAssociationRepositoryImpl extends AssociationRepositoryImpl<GroupObject, LicenseObject, Group2LicenseAssociationImpl, Group2LicenseAssociation> implements Group2LicenseAssociationRepository {
+public class Group2LicenseAssociationRepositoryImpl extends AssociationRepositoryImpl<FeatureObject, DistributionObject, Group2LicenseAssociationImpl, Feature2DistributionAssociation> implements Feature2DistributionAssociationRepository {
     private final static String XML_NODE = "groups2licenses";
 
     private final GroupRepositoryImpl m_groupRepository;

Modified: ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/GroupObjectImpl.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/GroupObjectImpl.java?rev=1301412&r1=1301411&r2=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/GroupObjectImpl.java (original)
+++ ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/GroupObjectImpl.java Fri Mar 16 10:05:14 2012
@@ -21,11 +21,11 @@ package org.apache.ace.client.repository
 import java.util.List;
 import java.util.Map;
 
-import org.apache.ace.client.repository.object.Artifact2GroupAssociation;
+import org.apache.ace.client.repository.object.Artifact2FeatureAssociation;
 import org.apache.ace.client.repository.object.ArtifactObject;
-import org.apache.ace.client.repository.object.Group2LicenseAssociation;
-import org.apache.ace.client.repository.object.GroupObject;
-import org.apache.ace.client.repository.object.LicenseObject;
+import org.apache.ace.client.repository.object.Feature2DistributionAssociation;
+import org.apache.ace.client.repository.object.FeatureObject;
+import org.apache.ace.client.repository.object.DistributionObject;
 
 import com.thoughtworks.xstream.io.HierarchicalStreamReader;
 
@@ -33,7 +33,7 @@ import com.thoughtworks.xstream.io.Hiera
  * Implementation class for the GroupObject. For 'what it does', see GroupObject,
  * for 'how it works', see RepositoryObjectImpl.
  */
-public class GroupObjectImpl extends RepositoryObjectImpl<GroupObject> implements GroupObject {
+public class GroupObjectImpl extends RepositoryObjectImpl<FeatureObject> implements FeatureObject {
     private final static String XML_NODE = "group";
 
     GroupObjectImpl(Map<String, String> attributes, Map<String, String> tags, ChangeNotifier notifier) {
@@ -52,8 +52,8 @@ public class GroupObjectImpl extends Rep
         return getAssociations(ArtifactObject.class);
     }
 
-    public List<LicenseObject> getLicenses() {
-        return getAssociations(LicenseObject.class);
+    public List<DistributionObject> getDistributions() {
+        return getAssociations(DistributionObject.class);
     }
 
     public String getDescription() {
@@ -72,12 +72,12 @@ public class GroupObjectImpl extends Rep
         addAttribute(KEY_NAME, name);
     }
 
-    public List<Artifact2GroupAssociation> getAssociationsWith(ArtifactObject artifact) {
-        return getAssociationsWith(artifact, ArtifactObject.class, Artifact2GroupAssociation.class);
+    public List<Artifact2FeatureAssociation> getAssociationsWith(ArtifactObject artifact) {
+        return getAssociationsWith(artifact, ArtifactObject.class, Artifact2FeatureAssociation.class);
     }
 
-    public List<Group2LicenseAssociation> getAssociationsWith(LicenseObject license) {
-        return getAssociationsWith(license, LicenseObject.class, Group2LicenseAssociation.class);
+    public List<Feature2DistributionAssociation> getAssociationsWith(DistributionObject license) {
+        return getAssociationsWith(license, DistributionObject.class, Feature2DistributionAssociation.class);
     }
 
     private static String[] DEFINING_KEYS = new String[] {KEY_NAME};

Modified: ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/GroupRepositoryImpl.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/GroupRepositoryImpl.java?rev=1301412&r1=1301411&r2=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/GroupRepositoryImpl.java (original)
+++ ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/GroupRepositoryImpl.java Fri Mar 16 10:05:14 2012
@@ -20,8 +20,8 @@ package org.apache.ace.client.repository
 
 import java.util.Map;
 
-import org.apache.ace.client.repository.object.GroupObject;
-import org.apache.ace.client.repository.repository.GroupRepository;
+import org.apache.ace.client.repository.object.FeatureObject;
+import org.apache.ace.client.repository.repository.FeatureRepository;
 
 import com.thoughtworks.xstream.io.HierarchicalStreamReader;
 
@@ -29,7 +29,7 @@ import com.thoughtworks.xstream.io.Hiera
  * Implementation class for the GroupRepository. For 'what it does', see GroupRepository,
  * for 'how it works', see ObjectRepositoryImpl.
  */
-public class GroupRepositoryImpl extends ObjectRepositoryImpl<GroupObjectImpl, GroupObject> implements GroupRepository {
+public class GroupRepositoryImpl extends ObjectRepositoryImpl<GroupObjectImpl, FeatureObject> implements FeatureRepository {
     private final static String XML_NODE = "groups";
 
     public GroupRepositoryImpl(ChangeNotifier notifier) {
--- ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Artifact2GroupAssociation.java (original)
+++ ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/Artifact2FeatureAssociation.java Fri Mar 16 10:05:14 2012
@@ -21,10 +21,10 @@ package org.apache.ace.client.repository
 import org.apache.ace.client.repository.Association;
 
 /**
  * Interface to a Artifact2GroupAssociation. Most functionality is defined by the generic Association.
  */
-public interface Artifact2GroupAssociation extends Association<ArtifactObject, GroupObject> {
-    public static final String TOPIC_ENTITY_ROOT = Artifact2GroupAssociation.class.getSimpleName() + "/";
+public interface Artifact2FeatureAssociation extends Association<ArtifactObject, FeatureObject> {
+    public static final String TOPIC_ENTITY_ROOT = Artifact2FeatureAssociation.class.getSimpleName() + "/";
 
     public static final String TOPIC_ADDED = PUBLIC_TOPIC_ROOT + TOPIC_ENTITY_ROOT + TOPIC_ADDED_SUFFIX;
     public static final String TOPIC_REMOVED = PUBLIC_TOPIC_ROOT + TOPIC_ENTITY_ROOT + TOPIC_REMOVED_SUFFIX;
@@ -21,10 +21,10 @@ package org.apache.ace.client.repository
 
 /**
- * Interface to a Artifact2GroupAssociation. Most functionality is defined by the generic Association.
+ * Interface to a Artifact2FeatureAssociation. Most functionality is defined by the generic Association.
  */

Modified: ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/ArtifactObject.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/ArtifactObject.java?rev=1301412&r1=1301411&r2=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/GroupObject.java (original)
+++ ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/FeatureObject.java Fri Mar 16 10:05:14 2012
@@ -23,14 +23,14 @@ import java.util.List;
 import org.apache.ace.client.repository.RepositoryObject;
 
 /**
  * Interface to a GroupObject. The basic functionality is defined by RepositoryObject, but extended for
  * Group-specific information.
  */
-public interface GroupObject extends RepositoryObject {
+public interface FeatureObject extends RepositoryObject {
     public static final String KEY_DESCRIPTION = "description";
     public static final String KEY_NAME = "name";
 
-    public static final String TOPIC_ENTITY_ROOT = GroupObject.class.getSimpleName() + "/";
+    public static final String TOPIC_ENTITY_ROOT = FeatureObject.class.getSimpleName() + "/";
 
     public static final String TOPIC_ADDED = PUBLIC_TOPIC_ROOT + TOPIC_ENTITY_ROOT + TOPIC_ADDED_SUFFIX;
     public static final String TOPIC_REMOVED = PUBLIC_TOPIC_ROOT + TOPIC_ENTITY_ROOT + TOPIC_REMOVED_SUFFIX;
@@ -42,35 +42,40 @@ public interface GroupObject extends Rep
      * are none, an empty list will be returned.
      */
     public List<ArtifactObject> getArtifacts();
+    
     /**
-     * Returns all <code>LicenseObject</code>s this object is associated with. If there
+     * Returns all <code>DistributionObject</code>s this object is associated with. If there
      * are none, an empty list will be returned.
      */
-    public List<LicenseObject> getLicenses();
+    public List<DistributionObject> getDistributions();
 
     /**
      * Returns all associations this group has with a given bundle.
      */
-    public List<Artifact2GroupAssociation> getAssociationsWith(ArtifactObject artifact);
+    public List<Artifact2FeatureAssociation> getAssociationsWith(ArtifactObject artifact);
+    
     /**
-     * Returns all associations this group has with a given license.
+     * Returns all associations this feature has with a given distribution.
      */
-    public List<Group2LicenseAssociation> getAssociationsWith(LicenseObject license);
+    public List<Feature2DistributionAssociation> getAssociationsWith(DistributionObject distribution);
 
     /**
      * Returns the name of this bundle.
      */
     public String getName();
+
     /**
      * Sets the name of this bundle.
      */
     public void setName(String name);
+    
     /**
      * Returns the description of this bundle.
      */
     public String getDescription();
+    
     /**
      * Sets the description of this bundle.
      */
     public void setDescription(String description);
 }
@@ -23,14 +23,14 @@ import java.util.List;
 
 /**
- * Interface to a GroupObject. The basic functionality is defined by RepositoryObject, but extended for
- * Group-specific information.
+ * Interface to a FeatureObject. The basic functionality is defined by RepositoryObject, but extended for
+ * feature-specific information.
  */
@@ -42,35 +42,40 @@ public interface GroupObject extends Rep
 
     /**
-     * Returns all associations this group has with a given bundle.
+     * Returns all associations this feature has with a given artifact.
      */
@@ -42,35 +42,40 @@ public interface GroupObject extends Rep
 
     /**
-     * Returns the name of this bundle.
+     * Returns the name of this feature.
      */
     public String getName();
@@ -42,35 +42,40 @@ public interface GroupObject extends Rep
     /**
-     * Sets the name of this bundle.
+     * Sets the name of this feature.
      */
     public void setName(String name);
@@ -42,35 +42,40 @@ public interface GroupObject extends Rep
     /**
-     * Returns the description of this bundle.
+     * Returns the description of this feature.
      */
     public String getDescription();
@@ -42,35 +42,40 @@ public interface GroupObject extends Rep
     /**
-     * Sets the description of this bundle.
+     * Sets the description of this feature.
      */
     public void setDescription(String description);

Modified: ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/TargetObject.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/object/TargetObject.java?rev=1301412&r1=1301411&r2=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Artifact2GroupAssociationRepository.java (original)
+++ ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/Artifact2FeatureAssociationRepository.java Fri Mar 16 10:05:14 2012
@@ -19,12 +19,12 @@
 package org.apache.ace.client.repository.repository;
 
 import org.apache.ace.client.repository.AssociationRepository;
-import org.apache.ace.client.repository.object.Artifact2GroupAssociation;
+import org.apache.ace.client.repository.object.Artifact2FeatureAssociation;
 import org.apache.ace.client.repository.object.ArtifactObject;
-import org.apache.ace.client.repository.object.GroupObject;
+import org.apache.ace.client.repository.object.FeatureObject;
 
 /**
  * Interface to a Artifact2GroupAssociationRepository. The functionality is defined by the generic AssociationRepository.
  */
-public interface Artifact2GroupAssociationRepository extends AssociationRepository<ArtifactObject, GroupObject, Artifact2GroupAssociation> {
+public interface Artifact2FeatureAssociationRepository extends AssociationRepository<ArtifactObject, FeatureObject, Artifact2FeatureAssociation> {
 }
@@ -19,12 +19,12 @@
 
 /**
- * Interface to a Artifact2GroupAssociationRepository. The functionality is defined by the generic AssociationRepository.
+ * Interface to a Artifact2FeatureAssociationRepository. The functionality is defined by the generic AssociationRepository.
  */

Modified: ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/ArtifactRepository.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/ArtifactRepository.java?rev=1301412&r1=1301411&r2=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/ArtifactRepository.java (original)
+++ ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/ArtifactRepository.java Fri Mar 16 10:05:14 2012
@@ -29,7 +29,7 @@ import org.apache.ace.client.repository.
 /**
  * Interface to a ArtifactRepository. The functionality is defined by the generic AssociationRepository.
  */
-public interface ArtifactRepository extends ObjectRepository<ArtifactObject>{
+public interface ArtifactRepository extends ObjectRepository<ArtifactObject> {
 	/**
 	 * Gets a list of all ArtifactObject's which are resource processing bundles.
 	 */
@@ -74,19 +74,19 @@ public interface ArtifactRepository exte
 	 * needs to be done, the original artifact's URL will be returned.
 	 * @param artifact An artifact
 	 * @param props A tree of properties objects, to be used for replacement.
 	 * @param gatewayID The gatewayID of the gateway for which this artifact is being processed.
 	 * @param version The deployment version for which this artifact is being processed.
 	 * @return A URL to a new, processed artifact, or to the original one, in case nothing needed to be processed.
      * @throws IOException Thrown if reading the original artifact goes wrong, or storing the processed one.
 	 */
-	public String preprocessArtifact(ArtifactObject artifact, TargetObject gateway, String gatewayID, String version) throws IOException ;
+	public String preprocessArtifact(ArtifactObject artifact, TargetObject target, String targetID, String version) throws IOException ;
 
     /**
      * Indicates whether the template should be processed again, given the properties, and the version to which it
      * should be compared.
      * @param url A string representing a URL to the original artifact.
      * @param props A PropertyResolver which can be used to fill in 'holes' in the template.
      * @param gatewayID The gatewayID of the gateway for which this artifact is being processed.
      * @param version The deployment version for which this artifact is being processed.
      * @param lastVersion The deployment version to which the current one should be compared.
      * @param newVersion The new, potential version.
@@ -94,7 +94,7 @@ public interface ArtifactRepository exte
      * @return Whether or not a new version has to be created.
      * @throws IOException
      */
-    public boolean needsNewVersion(ArtifactObject artifact, TargetObject gateway, String gatewayID, String fromVersion);
+    public boolean needsNewVersion(ArtifactObject artifact, TargetObject target, String targetID, String fromVersion);
 
 	/**
 	 * Sets the OBR that this artifact repository should use to upload artifacts to.
@@ -74,19 +74,19 @@ public interface ArtifactRepository exte
 	 * @param artifact An artifact
 	 * @param props A tree of properties objects, to be used for replacement.
-	 * @param gatewayID The gatewayID of the gateway for which this artifact is being processed.
+	 * @param targetID The targetID of the target for which this artifact is being processed.
 	 * @param version The deployment version for which this artifact is being processed.
 	 * @return A URL to a new, processed artifact, or to the original one, in case nothing needed to be processed.
@@ -74,19 +74,19 @@ public interface ArtifactRepository exte
      * @param url A string representing a URL to the original artifact.
      * @param props A PropertyResolver which can be used to fill in 'holes' in the template.
-     * @param gatewayID The gatewayID of the gateway for which this artifact is being processed.
+     * @param targetID The targetID of the target for which this artifact is being processed.
      * @param version The deployment version for which this artifact is being processed.
      * @param lastVersion The deployment version to which the current one should be compared.

Modified: ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/DeploymentVersionRepository.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/DeploymentVersionRepository.java?rev=1301412&r1=1301411&r2=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/GroupRepository.java (original)
+++ ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/repository/FeatureRepository.java Fri Mar 16 10:05:14 2012
@@ -19,10 +19,10 @@
 package org.apache.ace.client.repository.repository;
 
 import org.apache.ace.client.repository.ObjectRepository;
-import org.apache.ace.client.repository.object.GroupObject;
+import org.apache.ace.client.repository.object.FeatureObject;
 
 /**
  * Interface to a GroupRepository. The functionality is defined by the generic AssociationRepository.
  */
-public interface GroupRepository extends ObjectRepository<GroupObject> {
+public interface FeatureRepository extends ObjectRepository<FeatureObject> {
 }
@@ -19,10 +19,10 @@
 
 /**
- * Interface to a GroupRepository. The functionality is defined by the generic AssociationRepository.
+ * Interface to a FeatureRepository. The functionality is defined by the generic AssociationRepository.
  */

Modified: ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/stateful/StatefulTargetObject.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/stateful/StatefulTargetObject.java?rev=1301412&r1=1301411&r2=1301412&view=diff
==============================================================================
--- ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/stateful/StatefulTargetRepository.java (original)
+++ ace/trunk/ace-client-repository-api/src/main/java/org/apache/ace/client/repository/stateful/StatefulTargetRepository.java Fri Mar 16 10:05:14 2012
@@ -23,31 +23,31 @@ import java.util.Map;
 import org.apache.ace.client.repository.ObjectRepository;
 
 /**
  * Represents a repository of <ode>StatefulGatewayObject</code>'s.
  */
 public interface StatefulTargetRepository extends ObjectRepository<StatefulTargetObject> {
 
     /**
      * Registers a gateway with given attributes. This will result in the creation
      * of a <code>GatewayObject</code> in the <code>GatewayRepository</code>, and
      * the creation of a <code>StatefulGatewayObject</code>, which will also be
      * returned.
      * @param attributes The attributes to create the <code>GatewayObject</code> with.
      * @return The newly registered gateway object.
      */
     public StatefulTargetObject preregister(Map<String, String> attributes, Map<String, String> tags);
 
     /**
      * Unregisters a gateway, removing it from the <code>GatewayRepository</code>. Note
      * that a <code>StatefulGatewayObject</code> might stay around if it is backed
      * by audit log entries. If the given ID is not that of an existing <code>GatewayObject</code>,
      * an <code>IllegalArgumentException</code> will be thrown.
      * @param gatewayID A string representing a gateway ID.
      */
-    public void unregister(String gatewayID);
+    public void unregister(String targetID);
 
     /**
      * Explicitly instruct the <code>StatefulGatewayRepository</code> to update
      * its contents; for instance, after syncing the audit log.
      */
     public void refresh();
@@ -23,31 +23,31 @@ import java.util.Map;
 
 /**
- * Represents a repository of <ode>StatefulGatewayObject</code>'s.
+ * Represents a repository of <ode>StatefulTargetObject</code>'s.
  */
 public interface StatefulTargetRepository extends ObjectRepository<StatefulTargetObject> {
@@ -23,31 +23,31 @@ import java.util.Map;
 
     /**
-     * Registers a gateway with given attributes. This will result in the creation
-     * of a <code>GatewayObject</code> in the <code>GatewayRepository</code>, and
-     * the creation of a <code>StatefulGatewayObject</code>, which will also be
+     * Registers a target with given attributes. This will result in the creation
+     * of a <code>TargetObject</code> in the <code>TargetRepository</code>, and
+     * the creation of a <code>StatefulTargetObject</code>, which will also be
      * returned.
@@ -23,31 +23,31 @@ import java.util.Map;
      * returned.
-     * @param attributes The attributes to create the <code>GatewayObject</code> with.
-     * @return The newly registered gateway object.
+     * @param attributes The attributes to create the <code>TargetObject</code> with.
+     * @return The newly registered target object.
      */
     public StatefulTargetObject preregister(Map<String, String> attributes, Map<String, String> tags);
@@ -23,31 +23,31 @@ import java.util.Map;
 
     /**
-     * Unregisters a gateway, removing it from the <code>GatewayRepository</code>. Note
-     * that a <code>StatefulGatewayObject</code> might stay around if it is backed
-     * by audit log entries. If the given ID is not that of an existing <code>GatewayObject</code>,
+     * Unregisters a target, removing it from the <code>TargetRepository</code>. Note
+     * that a <code>StatefulTargetObject</code> might stay around if it is backed
+     * by audit log entries. If the given ID is not that of an existing <code>TargetObject</code>,
      * an <code>IllegalArgumentException</code> will be thrown.
@@ -23,31 +23,31 @@ import java.util.Map;
      * an <code>IllegalArgumentException</code> will be thrown.
-     * @param gatewayID A string representing a gateway ID.
+     * @param targetID A string representing a target ID.
      */
@@ -23,31 +23,31 @@ import java.util.Map;
 
     /**
-     * Explicitly instruct the <code>StatefulGatewayRepository</code> to update
+     * Explicitly instruct the <code>StatefulTargetRepository</code> to update
      * its contents; for instance, after syncing the audit log.
      */

Modified: ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Activator.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-client-repository-impl/src/main/java/org/apache/ace/client/repository/impl/Activator.java?rev=1301412&r1=1301411&r2=1301412&view=diff
==============================================================================